@@ -3,7 +3,17 @@ import pathlib
 
 import yaml
 
-__version__ = "0.5.9"
+__version__ = "0.6.0"
+
+from . import cfg
+
+
+def register(path):
+    path = pathlib.Path(path)
+    if path.is_file():
+        path = path.parent
+
+    cfg.cfg = load_config(path)
 
 
 def load_config(pkg_path):
